==> plf-community-sources-1.1.1.zip: platform-sources-1.1.1/social-6.1.1/component/service/src/main/java/org/exoplatform/social/rest/api/RestProperties.java <==
/*
 * Copyright (C) 2003-2015 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
*/

package org.exoplatform.social.rest.api;

public class RestProperties {

  public static final String ATTACHMENTS   = "attachments";
  public static final String CREATE_DATE   = "createDate";
  public static final String DISPLAY_NAME  = "displayName";
  public static final String ETAG          = "ETag";
  public static final String ID            = "id";
  public static final String IDENTITY      = "identity";
  public static final String MANAGERS      = "managers";
  public static final String MEMBERS       = "members";
  public static final String PENDING       = "pending";
  public static final String RECEIVER      = "receiver";
  public static final String RELATIONSHIPS = "relationships";
  public static final String SENDER        = "sender";
  public static final String TYPE          = "type";
  public static final String UPDATE_DATE   = "updateDate";
  public static final String LIKES         = "likes";
  public static final String SUB_COMMENTS      = "subComments";
}

==> plf-community-sources-4.4.3.zip: platform-sources-4.4.3/social-4.4.3/component/service/src/main/java/org/exoplatform/social/rest/api/RestProperties.java <==
/*
 * Copyright (C) 2003-2015 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
*/

package org.exoplatform.social.rest.api;

public class RestProperties {

  public static final String ATTACHMENTS   = "attachments";
  public static final String COMPANY       = "company";
  public static final String CREATE_DATE   = "createDate";
  public static final String DESCRIPTION   = "description";
  public static final String DISPLAY_NAME  = "displayName";
  public static final String END_DATE      = "endDate";
  public static final String ETAG          = "ETag";
  public static final String ID            = "id";
  public static final String IDENTITY      = "identity";
  public static final String IM_ID         = "imId";
  public static final String IM_TYPE       = "imType";
  public static final String IS_CURRENT    = "isCurrent";
  public static final String MANAGERS      = "managers";
  public static final String MEMBERS       = "members";
  public static final String PHONE_NUMBER  = "phoneNumber";
  public static final String PHONE_TYPE    = "phoneType";
  public static final String POSITION      = "position";
  public static final String RECEIVER      = "receiver";
  public static final String RELATIONSHIPS = "relationships";
  public static final String SENDER        = "sender";
  public static final String SKILLS        = "skills";
  public static final String START_DATE    = "startDate";
  public static final String TYPE          = "type";
  public static final String UPDATE_DATE   = "updateDate";
  public static final String URL           = "url";
}
